==> kaspaliste-0.4.tar.gz: kaspaliste-0.4/kaspaliste/klib/publbase.cpp <==
/***************************************************************************
                          publbase.cpp  -  description
                             -------------------
    begin                : Fri Sep 24 1999
    copyright            : (C) 1999 by Jan Mueller
    email                : janmueller7@hotmail.com
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "publbase.h"
#include <assert.h>
#define Inherited Table

// Creates new Publ
PublBase::PublBase(Sql *conn):Inherited("publ", conn) {
	initNew();
}

PublBase::PublBase(const char *dbname):Inherited("publ", dbname) {
	initNew();
}

void PublBase::initNew() {
  PublRec *publ=new PublRec;
  assert(publ);
  publ->empty();
  publ->id.set(newPubl());
  init(publ);
  asprintf(&_where, "where oid=%u", publ->id.get());
}

PublBase::PublBase(const char *where, const char *dbname):Inherited("publ", dbname) {
	initWhere(where);
}

PublBase::PublBase(const char *where, Sql *conn):Inherited("publ", conn) {
	initWhere(where);
}

void PublBase::initWhere(const char *where) {
  PublRec *publ=Inherited::getPubl(where);
  if(!publ) {
    publ=new PublRec;
    assert(publ);
    publ->empty();
    publ->id.set((Oid)InvalidOid);
  }
  init(publ);
	if(where)	_where=mystrdup(where);
	else _where=0L;
}

PublBase::~PublBase() {
}

KaspaRec *PublBase::invalid() {
		KaspaRec *publ=new PublRec;
		publ->id.set((Oid)InvalidOid);
		return publ;
}


KaspaRec *PublBase::read(const char *where) {
	return getPubl(where);
}	

void PublBase::write(const char *where, bool block) {
    updatePubl(publ(), where, block);
}

void PublBase::del(Oid o) {
    deletePubl(o);
    publ()->empty();
    publ()->id.set((Oid)InvalidOid);
}

PublRec *PublBase::publ() {
	if(!dynamic_cast<PublRec*>(rec))
		abort();
	return dynamic_cast<PublRec*>(rec);
}


Oid PublBase::createAuthor() {
	Oid o=newAuthor();
	newPublAuthor(publ()->id.get(), o);
	return o;
}

void PublBase::insertAuthor(Oid o) {
	newPublAuthor(publ()->id.get(), o);
}
	
void PublBase::removeAuthor(Oid o) {
	Str s="where authorno=";
	oid2str(o, &s);
	s+=" and publicationno=";
	oid2str(publ()->id.get(), &s);
	deletePublAuthor(s);
}

Oid PublBase::createPart() {
	return newPart(publ()->id.get());
}

void PublBase::deletePart(const char *where) {
	Inherited::deletePart(where);
}

Oid PublBase::createNote() {
	Oid o=newNote(publ()->id.get());
	insertLink(o);
	return o;
}

Oid PublBase::createPublisher() {
	Oid o=newPublisher();
	return o;
};

NoteTitle *PublBase::getNotes() {
	Str s="where publicationno=";
	oid2str(publ()->id.get(), &s);
	s+=" order by title";
	return getNoteTitles(s);
}


/**  */
int PublBase::bibTexIndex(Oid author, Oid publ){
	return KaspaBase::bibTexIndex(author, getYear(), publ);
}

==> kaspaliste-0.42.tar.gz: kaspaliste-0.42/kaspaliste/klib/publbase.cpp <==
/***************************************************************************
                          publbase.cpp  -  description
                             -------------------
    begin                : Fri Sep 24 1999
    copyright            : (C) 1999 by Jan Mueller
    email                : janmueller7@hotmail.com
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "publbase.h"
#include <assert.h>
#define Inherited Table

// Creates new Publ
PublBase::PublBase(Sql *conn):Inherited("publ", conn) {
	initNew();
}

PublBase::PublBase(const char *dbname):Inherited("publ", dbname) {
	initNew();
}

void PublBase::initNew() {
  PublRec *publ=new PublRec;
  assert(publ);
  publ->empty();
  publ->id.set(newPubl());
  init(publ);
  _where="where oid=";
  _where+=publ->id.get();
}

PublBase::PublBase(const char *where, const char *dbname):Inherited("publ", dbname) {
	initWhere(where);
}

PublBase::PublBase(const char *where, Sql *conn):Inherited("publ", conn) {
	initWhere(where);
}

void PublBase::initWhere(const char *where) {
  PublRec *publ=Inherited::getPubl(where);
  if(!publ) {
    publ=new PublRec;
    assert(publ);
    publ->empty();
    publ->id.set((Oid)InvalidOid);
  }
  init(publ);
	if(where)	_where=where;
	else _where="";
}

PublBase::~PublBase() {
}

KaspaRec *PublBase::invalid() {
		KaspaRec *publ=new PublRec;
		publ->id.set((Oid)InvalidOid);
		return publ;
}


KaspaRec *PublBase::read(const char *where) {
	return getPubl(where);
}	

void PublBase::write(const char *where, bool block) {
    updatePubl(publ(), where, block);
}

void PublBase::del(Oid o) {
    deletePubl(o);
    publ()->empty();
    publ()->id.set((Oid)InvalidOid);
}

PublRec *PublBase::publ() {
	if(!dynamic_cast<PublRec*>(rec))
		abort();
	return dynamic_cast<PublRec*>(rec);
}


Oid PublBase::createAuthor() {
	Oid o=newAuthor();
	newPublAuthor(publ()->id.get(), o);
	return o;
}

void PublBase::insertAuthor(Oid o) {
	newPublAuthor(publ()->id.get(), o);
}
	
void PublBase::removeAuthor(Oid o) {
	Str s="where authorno=";
	oid2str(o, &s);
	s+=" and publicationno=";
	oid2str(publ()->id.get(), &s);
	deletePublAuthor(s);
}

Oid PublBase::createPart() {
	return newPart(publ()->id.get());
}

void PublBase::deletePart(const char *where) {
	Inherited::deletePart(where);
}

Oid PublBase::createNote() {
	Oid o=newNote(publ()->id.get());
	insertLink(o);
	return o;
}

Oid PublBase::createPublisher() {
	Oid o=newPublisher();
	return o;
};

Oid PublBase::createJournal() {
	Oid o=newPublisher();
	return o;
};

NoteTitle *PublBase::getNotes() {
	Str s="where publicationno=";
	oid2str(publ()->id.get(), &s);
	s+=" order by title";
	return getNoteTitles(s);
}


/**  */
int PublBase::bibTexIndex(Oid author, Oid publ){
	return KaspaBase::bibTexIndex(author, getYear(), publ);
}
